/*
 * Created on 01.10.2004 by laliluna
 *
 */
package de.laliluna.tutorial.library.test;

import java.rmi.RemoteException;
import java.util.Properties;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import de.laliluna.tutorial.library.interfaces.*;

/**
 * @author laliluna
 *  
 */
public class TestLibraryManager {

  private Properties properties;

  public TestLibraryManager() {
    // [laliluna] the properties specifies where the JNDI lookups for the EJBs can be made
    properties = new Properties();
    properties.put("java.naming.factory.initial",
        "org.jnp.interfaces.NamingContextFactory");
    properties.put("java.naming.factory.url.pkgs",
        "org.jboss.naming:org.jnp.interfaces");
    properties.put("java.naming.provider.url", "jnp://localhost:1099");
    properties.put("jnp.disableDiscovery", "true");
  }

  public static void main(String[] args) {
    TestLibraryManager libraryManager = new TestLibraryManager();
    libraryManager.doTheTest();
  }

  public void doTheTest() throws EJBException {

    // [laliluna] a object we will use to convert the home interfaces
    Object object;
    try {
      // laliluna 01.10.2004 get context to find homeinterfaces in jndi
      // context
      Context context = new InitialContext(properties);

      // laliluna 01.10.2004 create a dummy book
      object = context.lookup(BookHome.JNDI_NAME);
      /*
       * [laliluna] 
       * when using the remote interface you have to use the PortableRemoteObject to convert the object to your class/interface
       * 
       */
      BookHome bookHome = (BookHome) PortableRemoteObject.narrow(object, BookHome.class);
      Book book = bookHome.create();
      book.setAvailable(true);
      book.setTitle("Learning EJBeing");

      // laliluna 01.10.2004 dummy variable to hold a book primaryKey
      Integer bookPrimaryKey = book.getId();

      // laliluna 01.10.2004 getting a session EJB
      object = context
          .lookup(LibraryManagerHome.JNDI_NAME);
      LibraryManagerHome libraryManagerHome = (LibraryManagerHome) PortableRemoteObject.narrow(object, LibraryManagerHome.class);
      LibraryManager libraryManager = libraryManagerHome.create();

      // laliluna 01.10.2004 lend a book
      System.out.println("book available:" + book.getAvailable());
      BookValue bookValue = libraryManager.lendBook(bookPrimaryKey);
      System.out.println("book available:" + book.getAvailable());
      libraryManager.returnBook(bookValue);
      System.out.println("book available:" + book.getAvailable());

    } catch (EJBException e) {
      e.printStackTrace();
    } catch (NamingException e) {
      e.printStackTrace();
    } catch (CreateException e) {
      e.printStackTrace();
    } catch (RemoteException e) {
      e.printStackTrace();
    }
  }

}